@@ -42,10 +42,9 @@ class BotManager(Client):
             )
 
     async def handle_flood_wait(self, wait_time: int):
-        logger.info(f"FloodWait: Sleeping for {wait_time} seconds.")
 
         await asyncio.sleep(wait_time)
-        try:self.powerup(self.app_name)
+        try:await self.powerup(self.app_name)
         except:pass
         
     def _safe_async(self, coro_func):
@@ -90,11 +89,9 @@ class BotManager(Client):
             except AccessTokenExpired:
                 logger.error(f"Access token expired (attempt {attempt + 1})")
             except Exception as e:
-                logger.error(f"Error starting Client (attempt {attempt + 1}): {e}")
+                logger.error(f"Error starting Client.Stoped !")
                 logger.error(traceback.format_exc())
-                if attempt < max_retries - 1:
-                    logger.info("Retrying in 10 seconds...")
-                    await asyncio.sleep(10)
+                break
         else:
             logger.error("Failed to start bot after all retry attempts")
 
@@ -131,7 +128,7 @@ class BotManager(Client):
             except Exception as e:
                 logger.error(f"Error sending stop confirmation for {self._bot_info.first_name}: {e}")
             await super().stop()
-            sys.exit(0)
+            await asyncio.sleep(3)
 
     async def reboot(self):
         try:
@@ -173,7 +170,8 @@ class BotManager(Client):
                     await self.send_message(chat_id=chat_id, text="Bot restarted successfully!",reply_to_message_id=Message_id-1,)
                     await self.delete_messages(chat_id=chat_id,message_ids=Message_id)
                 except:pass
-            os.remove('restart.txt')
+
+            if os.path.exists('restart.txt'):os.remove('restart.txt')
         else:
             try:await self.send_message(chat_id=self.LOGS, text=f"{self._bot_info.mention} started successfully!")
             except Exception as e:logger.error(f"Failed to send start notification: {e}")
